@@ -1,17 +1,9 @@
 from functools import partial
-import os
 import pickle
-import sys
 import time
 
 import numpy as np
-from numpy.testing import (
-    assert_,
-    assert_almost_equal,
-    assert_array_equal,
-    assert_equal,
-    suppress_warnings,
-)
+from numpy.testing import assert_, assert_array_equal, assert_equal, suppress_warnings
 import pytest
 
 from randomgen import (
@@ -29,7 +21,6 @@ from randomgen import (
     SPECK128,
     AESCounter,
     ChaCha,
-    Generator,
     LCG128Mix,
     Philox,
     Romu,
@@ -131,8 +122,8 @@ def warmup(rg, n=None):
     rg.standard_normal(n)
     rg.standard_normal(n, dtype=np.float32)
     rg.standard_normal(n, dtype=np.float32)
-    rg.integers(0, 2 ** 24, n, dtype=np.uint64)
-    rg.integers(0, 2 ** 48, n, dtype=np.uint64)
+    rg.integers(0, 2**24, n, dtype=np.uint64)
+    rg.integers(0, 2**48, n, dtype=np.uint64)
     rg.standard_gamma(11.0, n)
     rg.standard_gamma(11.0, n, dtype=np.float32)
     rg.random(n, dtype=np.float64)
@@ -146,7 +137,7 @@ class RNG(object):
         cls.bit_generator = Xoshiro256
         cls.advance = None
         cls.seed = [12345]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
@@ -161,9 +152,9 @@ class RNG(object):
 
     def init_generator(self, seed=None, mode="sequence"):
         if seed is not None:
-            return Generator(self.bit_generator(*seed, mode=mode))
+            return np.random.Generator(self.bit_generator(*seed, mode=mode))
         else:
-            return Generator(self.bit_generator(seed=seed, mode=mode))
+            return np.random.Generator(self.bit_generator(seed=seed, mode=mode))
 
     def _reset_state(self):
         self.rg.bit_generator.state = self.initial_state
@@ -215,7 +206,7 @@ class RNG(object):
             new_bit_gen = self.rg.bit_generator.jumped()
             assert isinstance(new_bit_gen, self.rg.bit_generator.__class__)
             assert_(comp_state(state, self.rg.bit_generator.state))
-            Generator(new_bit_gen).random(1000000)
+            np.random.Generator(new_bit_gen).random(1000000)
         else:
             bit_gen_name = self.rg.bit_generator.__class__.__name__
             pytest.skip("jumped is not supported by {0}".format(bit_gen_name))
@@ -325,9 +316,9 @@ class RNG(object):
 
     def test_reset_state(self):
         state = self.rg.bit_generator.state
-        int_1 = self.rg.integers(2 ** 31)
+        int_1 = self.rg.integers(2**31)
         self.rg.bit_generator.state = state
-        int_2 = self.rg.integers(2 ** 31)
+        int_2 = self.rg.integers(2**31)
         assert_(int_1 == int_2)
         with pytest.raises(TypeError):
             self.rg.bit_generator.state = [(k, v) for k, v in state.items()]
@@ -361,12 +352,12 @@ class RNG(object):
 
     def test_reset_state_uint32(self):
         rg = self.init_generator(seed=self.seed, mode="legacy")
-        rg.integers(0, 2 ** 24, 120, dtype=np.uint32)
+        rg.integers(0, 2**24, 120, dtype=np.uint32)
         state = rg.bit_generator.state
-        n1 = rg.integers(0, 2 ** 24, 10, dtype=np.uint32)
+        n1 = rg.integers(0, 2**24, 10, dtype=np.uint32)
         rg2 = self.init_generator()
         rg2.bit_generator.state = state
-        n2 = rg2.integers(0, 2 ** 24, 10, dtype=np.uint32)
+        n2 = rg2.integers(0, 2**24, 10, dtype=np.uint32)
         assert_array_equal(n1, n2)
 
     def test_reset_state_float(self):
@@ -389,22 +380,6 @@ class RNG(object):
         permuted = self.rg.permutation(original)
         assert_((original != permuted).any())
 
-    def test_tomaxint(self):
-        with pytest.deprecated_call():
-            vals = self.rg.tomaxint(size=100000)
-        maxsize = 0
-        if os.name == "nt":
-            maxsize = 2 ** 31 - 1
-        else:
-            try:
-                maxsize = sys.maxint
-            except AttributeError:
-                maxsize = sys.maxsize
-        if maxsize < 2 ** 32:
-            assert_((vals < sys.maxsize).all())
-        else:
-            assert_((vals >= 2 ** 32).any())
-
     def test_beta(self):
         vals = self.rg.beta(2.0, 2.0, 10)
         assert_(len(vals) == 10)
@@ -464,40 +439,6 @@ class RNG(object):
         vals = self.rg.negative_binomial(10, 0.2, 10)
         assert_(len(vals) == 10)
 
-    def test_rand(self):
-        state = self.rg.bit_generator.state
-        with pytest.deprecated_call():
-            vals = self.rg.rand(10, 10, 10)
-        self.rg.bit_generator.state = state
-        assert_((vals == self.rg.random((10, 10, 10))).all())
-        assert_(vals.shape == (10, 10, 10))
-        with pytest.deprecated_call():
-            vals = self.rg.rand(10, 10, 10, dtype=np.float32)
-        assert_(vals.shape == (10, 10, 10))
-
-    def test_randn(self):
-        state = self.rg.bit_generator.state
-        with pytest.deprecated_call():
-            vals = self.rg.randn(10, 10, 10)
-        self.rg.bit_generator.state = state
-        vals2 = self.rg.standard_normal((10, 10, 10))
-        assert_equal(vals, vals2)
-        assert_equal(vals.shape, (10, 10, 10))
-
-        state = self.rg.bit_generator.state
-        with pytest.deprecated_call():
-            vals = self.rg.randn(10, 10, 10)
-        self.rg.bit_generator.state = state
-        assert_equal(vals, self.rg.standard_normal((10, 10, 10)))
-
-        state = self.rg.bit_generator.state
-        with pytest.deprecated_call():
-            self.rg.randn(10, 10, 10)
-        self.rg.bit_generator.state = state
-        with pytest.deprecated_call():
-            vals = self.rg.randn(10, 10, 10, dtype=np.float32)
-        assert_(vals.shape == (10, 10, 10))
-
     def test_noncentral_chisquare(self):
         vals = self.rg.noncentral_chisquare(10, 2, 10)
         assert_(len(vals) == 10)
@@ -538,7 +479,7 @@ class RNG(object):
     def test_random_integers(self):
         with suppress_warnings() as sup:
             sup.record(DeprecationWarning)
-            vals = self.rg.random_integers(10, 20, 10)
+            vals = self.rg.integers(10, 20, 10)
         assert_(len(vals) == 10)
 
     def test_rayleigh(self):
@@ -601,6 +542,7 @@ class RNG(object):
         s = self.rg.dirichlet((10, 5, 3), 20)
         assert_(s.shape == (20, 3))
 
+    @pytest.mark.skip(reason="Doesn't work since can't register bit generators")
     def test_pickle(self):
         pick = pickle.dumps(self.rg)
         unpick = pickle.loads(pick)
@@ -662,9 +604,9 @@ class RNG(object):
 
     def test_seed_array_error(self):
         if self.seed_vector_bits == 32:
-            out_of_bounds = 2 ** 32
+            out_of_bounds = 2**32
         else:
-            out_of_bounds = 2 ** 64
+            out_of_bounds = 2**64
 
         seed = -1
         with pytest.raises(ValueError):
@@ -921,81 +863,6 @@ class RNG(object):
         with pytest.raises(ValueError):
             self.rg.integers([0], [0], dtype=dtype)
 
-    def test_complex_normal(self):
-        st = self.rg.bit_generator.state
-        vals = self.rg.complex_normal(2.0 + 7.0j, 10.0, 5.0 - 5.0j, size=10)
-        assert_(len(vals) == 10)
-
-        self.rg.bit_generator.state = st
-        vals2 = [
-            self.rg.complex_normal(2.0 + 7.0j, 10.0, 5.0 - 5.0j) for _ in range(10)
-        ]
-        np.testing.assert_allclose(vals, vals2)
-
-        self.rg.bit_generator.state = st
-        vals3 = self.rg.complex_normal(
-            2.0 + 7.0j * np.ones(10), 10.0 * np.ones(1), 5.0 - 5.0j
-        )
-        np.testing.assert_allclose(vals, vals3)
-
-        self.rg.bit_generator.state = st
-        norms = self.rg.standard_normal(size=20)
-        norms = np.reshape(norms, (10, 2))
-        cov = 0.5 * (-5.0)
-        v_real = 7.5
-        v_imag = 2.5
-        rho = cov / np.sqrt(v_real * v_imag)
-        imag = 7 + np.sqrt(v_imag) * (
-            rho * norms[:, 0] + np.sqrt(1 - rho ** 2) * norms[:, 1]
-        )
-        real = 2 + np.sqrt(v_real) * norms[:, 0]
-        vals4 = [re + im * (0 + 1.0j) for re, im in zip(real, imag)]
-
-        np.testing.assert_allclose(vals4, vals)
-
-    def test_complex_normal_bm(self):
-        st = self.rg.bit_generator.state
-        vals = self.rg.complex_normal(2.0 + 7.0j, 10.0, 5.0 - 5.0j, size=10)
-        assert_(len(vals) == 10)
-
-        self.rg.bit_generator.state = st
-        vals2 = [
-            self.rg.complex_normal(2.0 + 7.0j, 10.0, 5.0 - 5.0j) for _ in range(10)
-        ]
-        np.testing.assert_allclose(vals, vals2)
-
-        self.rg.bit_generator.state = st
-        vals3 = self.rg.complex_normal(
-            2.0 + 7.0j * np.ones(10), 10.0 * np.ones(1), 5.0 - 5.0j
-        )
-        np.testing.assert_allclose(vals, vals3)
-
-    def test_complex_normal_zero_variance(self):
-        st = self.rg.bit_generator.state
-        c = self.rg.complex_normal(0, 1.0, 1.0)
-        assert_almost_equal(c.imag, 0.0)
-        self.rg.bit_generator.state = st
-        n = self.rg.standard_normal()
-        np.testing.assert_allclose(c, n, atol=1e-8)
-
-        st = self.rg.bit_generator.state
-        c = self.rg.complex_normal(0, 1.0, -1.0)
-        assert_almost_equal(c.real, 0.0)
-        self.rg.bit_generator.state = st
-        self.rg.standard_normal()
-        n = self.rg.standard_normal()
-        assert_almost_equal(c.real, 0.0)
-        np.testing.assert_allclose(c.imag, n, atol=1e-8)
-
-    def test_random_uintegers(self):
-        assert len(self.rg.uintegers(10)) == 10
-        assert len(self.rg.uintegers(10, bits=32)) == 10
-        assert isinstance(self.rg.uintegers(), int)
-        assert isinstance(self.rg.uintegers(bits=32), int)
-        with pytest.raises(ValueError):
-            with pytest.deprecated_call():
-                self.rg.random_uintegers(bits=128)
-
     def test_bit_generator_raw_large(self):
         bg = self.rg.bit_generator
         state = bg.state
@@ -1029,8 +896,8 @@ class TestMT19937(RNG):
         super().setup_class()
         cls.bit_generator = MT19937
         cls.advance = None
-        cls.seed = [2 ** 21 + 2 ** 16 + 2 ** 5 + 1]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.seed = [2**21 + 2**16 + 2**5 + 1]
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 32
         cls._extra_setup()
@@ -1052,8 +919,8 @@ class TestMT64(RNG):
         super().setup_class()
         cls.bit_generator = MT64
         cls.advance = None
-        cls.seed = [2 ** 43 + 2 ** 21 + 2 ** 16 + 2 ** 5 + 1]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.seed = [2**43 + 2**21 + 2**16 + 2**5 + 1]
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
@@ -1067,7 +934,7 @@ class TestJSF64(RNG):
         cls.bit_generator = partial(JSF, seed_size=3)
         cls.advance = None
         cls.seed = [12345]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
@@ -1080,7 +947,7 @@ class TestJSF32(RNG):
         cls.bit_generator = partial(JSF, size=32, seed_size=3)
         cls.advance = None
         cls.seed = [12345]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
@@ -1091,12 +958,12 @@ class TestPCG64(RNG):
     def setup_class(cls):
         super().setup_class()
         cls.bit_generator = PCG64
-        cls.advance = 2 ** 96 + 2 ** 48 + 2 ** 21 + 2 ** 16 + 2 ** 5 + 1
+        cls.advance = 2**96 + 2**48 + 2**21 + 2**16 + 2**5 + 1
         cls.seed = [
-            2 ** 96 + 2 ** 48 + 2 ** 21 + 2 ** 16 + 2 ** 5 + 1,
-            2 ** 21 + 2 ** 16 + 2 ** 5 + 1,
+            2**96 + 2**48 + 2**21 + 2**16 + 2**5 + 1,
+            2**21 + 2**16 + 2**5 + 1,
         ]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = None
         cls._extra_setup()
@@ -1104,9 +971,9 @@ class TestPCG64(RNG):
     def test_seed_array_error(self):
         # GH #82 for error type changes
         if self.seed_vector_bits == 32:
-            out_of_bounds = 2 ** 32
+            out_of_bounds = 2**32
         else:
-            out_of_bounds = 2 ** 64
+            out_of_bounds = 2**64
 
         seed = -1
         with pytest.raises(ValueError):
@@ -1134,7 +1001,7 @@ class TestPCG64VariantDXSM(TestPCG64):
     def setup_class(cls):
         super().setup_class()
         cls.bit_generator = partial(PCG64, variant="dxsm-128")
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls._extra_setup()
 
@@ -1144,7 +1011,7 @@ class TestPCG64CMDXSM(TestPCG64):
     def setup_class(cls):
         super().setup_class()
         cls.bit_generator = partial(PCG64, variant="dxsm")
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls._extra_setup()
 
@@ -1157,9 +1024,9 @@ class TestPhilox4x64(RNG):
         cls.width = 64
         cls.bit_generator_base = Philox
         cls.bit_generator = partial(Philox, number=cls.number, width=cls.width)
-        cls.advance = 2 ** 63 + 2 ** 31 + 2 ** 15 + 1
+        cls.advance = 2**63 + 2**31 + 2**15 + 1
         cls.seed = [12345]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls.max_vector_seed_size = 1
@@ -1183,9 +1050,9 @@ class TestPhilox2x64(TestPhilox4x64):
         cls.number = 2
         cls.width = 64
         cls.bit_generator = partial(Philox, number=cls.number, width=cls.width)
-        cls.advance = 2 ** 63 + 2 ** 31 + 2 ** 15 + 1
+        cls.advance = 2**63 + 2**31 + 2**15 + 1
         cls.seed = [12345]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls.max_vector_seed_size = 1
@@ -1199,9 +1066,9 @@ class TestPhilox2x32(TestPhilox4x64):
         cls.number = 2
         cls.width = 32
         cls.bit_generator = partial(Philox, number=cls.number, width=cls.width)
-        cls.advance = 2 ** 63 + 2 ** 31 + 2 ** 15 + 1
+        cls.advance = 2**63 + 2**31 + 2**15 + 1
         cls.seed = [12345]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
@@ -1214,9 +1081,9 @@ class TestPhilox4x32(TestPhilox4x64):
         cls.number = 4
         cls.width = 32
         cls.bit_generator = partial(Philox, number=cls.number, width=cls.width)
-        cls.advance = 2 ** 63 + 2 ** 31 + 2 ** 15 + 1
+        cls.advance = 2**63 + 2**31 + 2**15 + 1
         cls.seed = [12345]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
@@ -1230,9 +1097,9 @@ class TestThreeFry4x64(TestPhilox4x64):
         cls.width = 64
         cls.bit_generator_base = ThreeFry
         cls.bit_generator = partial(ThreeFry, number=cls.number, width=cls.width)
-        cls.advance = 2 ** 63 + 2 ** 31 + 2 ** 15 + 1
+        cls.advance = 2**63 + 2**31 + 2**15 + 1
         cls.seed = [12345]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
@@ -1245,9 +1112,9 @@ class TestThreeFry2x64(TestPhilox4x64):
         cls.number = 2
         cls.width = 64
         cls.bit_generator = partial(ThreeFry, number=cls.number, width=cls.width)
-        cls.advance = 2 ** 63 + 2 ** 31 + 2 ** 15 + 1
+        cls.advance = 2**63 + 2**31 + 2**15 + 1
         cls.seed = [12345]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
@@ -1260,9 +1127,9 @@ class TestThreeFry2x32(TestPhilox4x64):
         cls.number = 2
         cls.width = 32
         cls.bit_generator = partial(ThreeFry, number=cls.number, width=cls.width)
-        cls.advance = 2 ** 63 + 2 ** 31 + 2 ** 15 + 1
+        cls.advance = 2**63 + 2**31 + 2**15 + 1
         cls.seed = [12345]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
@@ -1275,9 +1142,9 @@ class TestThreeFry4x32(TestPhilox4x64):
         cls.number = 4
         cls.width = 32
         cls.bit_generator = partial(ThreeFry, number=cls.number, width=cls.width)
-        cls.advance = 2 ** 63 + 2 ** 31 + 2 ** 15 + 1
+        cls.advance = 2**63 + 2**31 + 2**15 + 1
         cls.seed = [12345]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
@@ -1290,7 +1157,7 @@ class TestXoroshiro128(RNG):
         cls.bit_generator = Xoroshiro128
         cls.advance = None
         cls.seed = [12345]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
@@ -1301,7 +1168,7 @@ class TestXoroshiro128PlusPlus(RNG):
     def setup_class(cls):
         super().setup_class()
         cls.bit_generator = partial(Xoroshiro128, plusplus=True)
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls._extra_setup()
 
@@ -1313,7 +1180,7 @@ class TestXoshiro256(RNG):
         cls.bit_generator = Xoshiro256
         cls.advance = None
         cls.seed = [12345]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
@@ -1326,7 +1193,7 @@ class TestXoshiro512(RNG):
         cls.bit_generator = Xoshiro512
         cls.advance = None
         cls.seed = [12345]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
@@ -1339,7 +1206,7 @@ class TestXorshift1024(RNG):
         cls.bit_generator = Xorshift1024
         cls.advance = None
         cls.seed = [12345]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
@@ -1352,7 +1219,7 @@ class TestDSFMT(RNG):
         cls.bit_generator = DSFMT
         cls.advance = None
         cls.seed = [12345]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls._extra_setup()
         cls.seed_vector_bits = 32
@@ -1365,7 +1232,7 @@ class TestSFMT(RNG):
         cls.bit_generator = SFMT
         cls.advance = None
         cls.seed = [12345]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls._extra_setup()
         cls.seed_vector_bits = 32
@@ -1395,12 +1262,12 @@ class TestPCG32(TestPCG64):
     def setup_class(cls):
         super().setup_class()
         cls.bit_generator = PCG32
-        cls.advance = 2 ** 48 + 2 ** 21 + 2 ** 16 + 2 ** 5 + 1
+        cls.advance = 2**48 + 2**21 + 2**16 + 2**5 + 1
         cls.seed = [
-            2 ** 48 + 2 ** 21 + 2 ** 16 + 2 ** 5 + 1,
-            2 ** 21 + 2 ** 16 + 2 ** 5 + 1,
+            2**48 + 2**21 + 2**16 + 2**5 + 1,
+            2**21 + 2**16 + 2**5 + 1,
         ]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = None
         cls._extra_setup()
@@ -1411,9 +1278,9 @@ class TestAESCounter(RNG):
     def setup_class(cls):
         super().setup_class()
         cls.bit_generator = AESCounter
-        cls.advance = 2 ** 63 + 2 ** 31 + 2 ** 15 + 1
-        cls.seed = [2 ** 21 + 2 ** 16 + 2 ** 5 + 1]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.advance = 2**63 + 2**31 + 2**15 + 1
+        cls.seed = [2**21 + 2**16 + 2**5 + 1]
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
@@ -1426,9 +1293,9 @@ class TestChaCha(RNG):
     def setup_class(cls):
         super().setup_class()
         cls.bit_generator = ChaCha
-        cls.advance = 2 ** 63 + 2 ** 31 + 2 ** 15 + 1
-        cls.seed = [2 ** 21 + 2 ** 16 + 2 ** 5 + 1]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.advance = 2**63 + 2**31 + 2**15 + 1
+        cls.seed = [2**21 + 2**16 + 2**5 + 1]
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
@@ -1440,8 +1307,8 @@ class TestHC128(RNG):
     def setup_class(cls):
         super().setup_class()
         cls.bit_generator = HC128
-        cls.seed = [2 ** 231 + 2 ** 21 + 2 ** 16 + 2 ** 5 + 1]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.seed = [2**231 + 2**21 + 2**16 + 2**5 + 1]
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
@@ -1453,9 +1320,9 @@ class TestSPECK128(RNG):
     def setup_class(cls):
         super().setup_class()
         cls.bit_generator = SPECK128
-        cls.seed = [2 ** 231 + 2 ** 21 + 2 ** 16 + 2 ** 5 + 1]
-        cls.rg = Generator(cls.bit_generator(*cls.seed, mode="legacy"))
-        cls.advance = 2 ** 63 + 2 ** 31 + 2 ** 15 + 1
+        cls.seed = [2**231 + 2**21 + 2**16 + 2**5 + 1]
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed, mode="legacy"))
+        cls.advance = 2**63 + 2**31 + 2**15 + 1
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
@@ -1467,17 +1334,17 @@ class TestLXM(RNG):
     def setup_class(cls):
         super().setup_class()
         cls.bit_generator = LXM
-        cls.seed = [2 ** 231 + 2 ** 21 + 2 ** 16 + 2 ** 5 + 1]
-        cls.rg = Generator(cls.bit_generator(*cls.seed))
-        cls.advance = 2 ** 63 + 2 ** 31 + 2 ** 15 + 1
+        cls.seed = [2**231 + 2**21 + 2**16 + 2**5 + 1]
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed))
+        cls.advance = 2**63 + 2**31 + 2**15 + 1
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
         cls.seed_error = ValueError
-        cls.out_of_bounds = 2 ** 192 + 1
+        cls.out_of_bounds = 2**192 + 1
 
     def init_generator(self, seed=None, mode="sequence"):
-        return Generator(self.bit_generator(seed=seed))
+        return np.random.Generator(self.bit_generator(seed=seed))
 
 
 class TestLCG128Mix(RNG):
@@ -1485,17 +1352,17 @@ class TestLCG128Mix(RNG):
     def setup_class(cls):
         super().setup_class()
         cls.bit_generator = LCG128Mix
-        cls.seed = [2 ** 231 + 2 ** 21 + 2 ** 16 + 2 ** 5 + 1]
-        cls.rg = Generator(cls.bit_generator(*cls.seed))
-        cls.advance = 2 ** 63 + 2 ** 31 + 2 ** 15 + 1
+        cls.seed = [2**231 + 2**21 + 2**16 + 2**5 + 1]
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed))
+        cls.advance = 2**63 + 2**31 + 2**15 + 1
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
         cls.seed_error = ValueError
-        cls.out_of_bounds = 2 ** 192 + 1
+        cls.out_of_bounds = 2**192 + 1
 
     def init_generator(self, seed=None, mode="sequence"):
-        return Generator(self.bit_generator(seed=seed))
+        return np.random.Generator(self.bit_generator(seed=seed))
 
 
 class TestPCG64DXSM(TestLCG128Mix):
@@ -1503,14 +1370,14 @@ class TestPCG64DXSM(TestLCG128Mix):
     def setup_class(cls):
         super().setup_class()
         cls.bit_generator = PCG64DXSM
-        cls.seed = [2 ** 231 + 2 ** 21 + 2 ** 16 + 2 ** 5 + 1]
-        cls.rg = Generator(cls.bit_generator(*cls.seed))
-        cls.advance = 2 ** 63 + 2 ** 31 + 2 ** 15 + 1
+        cls.seed = [2**231 + 2**21 + 2**16 + 2**5 + 1]
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed))
+        cls.advance = 2**63 + 2**31 + 2**15 + 1
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
         cls.seed_error = ValueError
-        cls.out_of_bounds = 2 ** 192 + 1
+        cls.out_of_bounds = 2**192 + 1
 
 
 class TestEFIIX64(TestLCG128Mix):
@@ -1518,14 +1385,14 @@ class TestEFIIX64(TestLCG128Mix):
     def setup_class(cls):
         super().setup_class()
         cls.bit_generator = EFIIX64
-        cls.seed = [2 ** 231 + 2 ** 21 + 2 ** 16 + 2 ** 5 + 1]
-        cls.rg = Generator(cls.bit_generator(*cls.seed))
-        cls.advance = 2 ** 63 + 2 ** 31 + 2 ** 15 + 1
+        cls.seed = [2**231 + 2**21 + 2**16 + 2**5 + 1]
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed))
+        cls.advance = 2**63 + 2**31 + 2**15 + 1
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
         cls.seed_error = ValueError
-        cls.out_of_bounds = 2 ** 192 + 1
+        cls.out_of_bounds = 2**192 + 1
 
 
 class TestRomu(TestLCG128Mix):
@@ -1533,11 +1400,11 @@ class TestRomu(TestLCG128Mix):
     def setup_class(cls):
         super().setup_class()
         cls.bit_generator = Romu
-        cls.seed = [2 ** 231 + 2 ** 21 + 2 ** 16 + 2 ** 5 + 1]
-        cls.rg = Generator(cls.bit_generator(*cls.seed))
-        cls.advance = 2 ** 63 + 2 ** 31 + 2 ** 15 + 1
+        cls.seed = [2**231 + 2**21 + 2**16 + 2**5 + 1]
+        cls.rg = np.random.Generator(cls.bit_generator(*cls.seed))
+        cls.advance = 2**63 + 2**31 + 2**15 + 1
         cls.initial_state = cls.rg.bit_generator.state
         cls.seed_vector_bits = 64
         cls._extra_setup()
         cls.seed_error = ValueError
-        cls.out_of_bounds = 2 ** 192 + 1
+        cls.out_of_bounds = 2**192 + 1
